@@ -2,6 +2,7 @@ import matplotlib.pyplot as plt
 import numpy as np
 
 import _base
+from typing import Dict
 
 fig, ax = plt.subplots()
 plt.subplots_adjust(left=0.2)
@@ -14,7 +15,7 @@ ax.set_yticklabels(['base flow', 'bankfull flow'])
 ax.set_xlabel('calendar day')
 ax.set_ylim(0.9, 3.1)
 
-bbox = dict(boxstyle="round", fc="0.8")
+bbox: Dict[str, str] = dict(boxstyle="round", fc="0.8")
 _cs0 = "angle,angleA=-10,angleB=-60,rad=10"
 ax.annotate('start event', xy=(95, 1.1), xytext=(0, 1.4),
             bbox=bbox, arrowprops=dict(arrowstyle="->", connectionstyle=_cs0))
