@@ -8,8 +8,6 @@ import sys
 from math import floor
 import numpy as np
 
-from scipy.sparse import lil_matrix, csr_matrix
-
 from netCDF4 import Dataset
 import time as time_lib
 import yaml
@@ -23,7 +21,7 @@ from . import sed_tools
 
 class init_tools(abc.ABC):
 
-    def init_output_infrastructure(self):
+    def init_output_infrastructure(self) -> None:
         """Initialize the output infrastructure (folder and save lists).
 
         This method is the first called in the initialization of the
@@ -42,7 +40,7 @@ class init_tools(abc.ABC):
         self._save_var_list = dict()  # dict of variables to save
         self._save_var_list['meta'] = dict()  # set up meta dict
 
-    def init_logger(self):
+    def init_logger(self) -> None:
         """Initialize a logger.
 
         The logger is initialized regardless of the value of ``self.verbose``.
@@ -73,7 +71,7 @@ class init_tools(abc.ABC):
         self.log_info('Platform: {}'.format(platform.platform()),
                       verbosity=0)  # log the os
 
-    def import_files(self, kwargs_dict={}):
+    def import_files(self, kwargs_dict={}) -> None:
         """Import the input files.
 
         This method handles the parsing and validation of any options supplied
@@ -172,6 +170,33 @@ class init_tools(abc.ABC):
                 # set using default value
                 input_file_vars[k] = v['default']
 
+        # compare the processed inputs with the total inputs. If any unused
+        # parameters exist, we warn the user that they are not being used! A
+        # special warning is issued for the Preprocessor advanced config
+        # keywords, which cannot be passed directly to the DeltaModel.
+        pp_only_kw = ['matrix', 'ensemble', 'set', 'parallel']
+        unused_user_keys = [k for k, v in user_dict.items() if not
+                            (k in input_file_vars.keys())]
+        if len(unused_user_keys) > 0:
+            any_in_preprocessor = [k for k in unused_user_keys if
+                                   (k in pp_only_kw)]
+            if len(any_in_preprocessor):
+                warnings.warn(UserWarning(
+                    'A Preprocessor-only keyword was specified as input in '
+                    'yaml file or kwargs: {0}. Advanced configurations '
+                    'are only supported by the Preprocessor via the '
+                    'high-level API. Any parameters specified as part of this '
+                    'advanced keyword configuration will not be used!'.format(
+                        any_in_preprocessor)))
+            else:
+                warnings.warn(UserWarning(
+                    'One or more inputs in yaml file or kwargs were unused by '
+                    'the model during instantiation. '
+                    'The unused keys are: {0}'.format(str(unused_user_keys))))
+
+        # note, the specified parameters are assigned to the model object in
+        # the following function `process_input_to_model`.
+
         # save the input file as a hidden attr and grab needed value
         self._input_file_vars = input_file_vars
         self.out_dir = self._input_file_vars['out_dir']
@@ -181,7 +206,7 @@ class init_tools(abc.ABC):
         else:
             self._netcdf_coords = ('time', 'x', 'y')
 
-    def process_input_to_model(self):
+    def process_input_to_model(self) -> None:
         """Process input file to model variables.
 
         Loop through the items specified in the model configuration and apply
@@ -210,7 +235,7 @@ class init_tools(abc.ABC):
                     var=k, val=v)
                 self.log_info(_msg, verbosity=0)
 
-    def determine_random_seed(self):
+    def determine_random_seed(self) -> None:
         """Set the random seed if given.
 
         If a random seed is specified, set the seed to this value.
@@ -227,12 +252,12 @@ class init_tools(abc.ABC):
         _msg = 'Random seed is: %s ' % str(self._seed)
         self.log_info(_msg, verbosity=0)
 
-    def create_other_variables(self):
+    def create_other_variables(self) -> None:
         """Model implementation variables.
 
         Creates variables for model implementation, from specified boundary
         condition variables. This method is run during initial model
-        instantition. Internally, this method calls :obj:`set_constants` and
+        instantiation. Internally, this method calls :obj:`set_constants` and
         :obj:`create_boundary_conditions`.
 
         .. note::
@@ -282,7 +307,7 @@ class init_tools(abc.ABC):
 
         self._is_finalized = False
 
-    def set_constants(self):
+    def set_constants(self) -> None:
         """Set the model constants.
 
         Configure constants, including coordinates and distances, as well as
@@ -342,7 +367,7 @@ class init_tools(abc.ABC):
                                  [1, 0, 1],
                                  [1, 1, 1]]).astype(np.int64)
 
-    def create_boundary_conditions(self):
+    def create_boundary_conditions(self) -> None:
         """Create model boundary conditions
 
         This method is run during model initialization to determine the
@@ -415,7 +440,7 @@ class init_tools(abc.ABC):
         self.diffusion_multiplier = (self._dt / self.N_crossdiff * self._alpha
                                      * 0.5 / self._dx**2)
 
-    def create_domain(self):
+    def create_domain(self) -> None:
         """Create the model domain.
 
         This method initializes the model domain, including coordinate arrays,
@@ -427,7 +452,7 @@ class init_tools(abc.ABC):
 
             If you need to modify the model domain after it has been created,
             it is probably safe to modify attributes directly, but take care
-            to ensure any dependent fields are also approrpriately changed.
+            to ensure any dependent fields are also appropriately changed.
         """
         _msg = 'Creating model domain'
         self.log_info(_msg, verbosity=1)
@@ -471,6 +496,11 @@ class init_tools(abc.ABC):
             (self._Np_water, self.size_indices), dtype=np.int64)
         self.sfc_visit = np.zeros_like(self.depth)
         self.sfc_sum = np.zeros_like(self.depth)
+        
+        # arrays acting as modifying hooks
+        self.mod_water_weight = np.ones_like(self.depth)
+        self.mod_sed_weight = np.ones_like(self.depth)
+        self.mod_erosion = np.ones_like(self.depth)
 
         # ---- domain ----
         cell_land = -2
@@ -521,7 +551,7 @@ class init_tools(abc.ABC):
         self.inlet = np.array(np.unique(np.where(self.cell_type == 1)[1]))
         self.eta[:] = self.stage - self.depth
 
-    def init_sediment_routers(self):
+    def init_sediment_routers(self) -> None:
         """Initialize the sediment router object here.
 
         These are preinitialized because the "boxing" for jitted functions is
@@ -543,7 +573,7 @@ class init_tools(abc.ABC):
                                        self.iwalk_flat, self.jwalk_flat,
                                        self.distances_flat, self.dry_depth,
                                        self._lambda, self._beta,  self.stepmax,
-                                       self.theta_mud)
+                                       self.theta_mud, self.mod_erosion)
         # initialize the SandRouter object
         self._sr = sed_tools.SandRouter(self._dt, self._dx, self.Vp_sed,
                                         self.u_max, self.qs0, self._u0,
@@ -553,9 +583,9 @@ class init_tools(abc.ABC):
                                         self.iwalk_flat, self.jwalk_flat,
                                         self.distances_flat, self.dry_depth,
                                         self._beta, self.stepmax,
-                                        self.theta_sand)
+                                        self.theta_sand, self.mod_erosion)
 
-    def init_output_file(self):
+    def init_output_file(self) -> None:
         """Creates a netCDF file to store output grids.
 
         Fills with default variables.
@@ -679,7 +709,7 @@ class init_tools(abc.ABC):
             _msg = 'Output netCDF file created'
             self.log_info(_msg, verbosity=2)
 
-    def init_subsidence(self):
+    def init_subsidence(self) -> None:
         """Initialize subsidence pattern.
 
         Initializes patterns of subsidence if toggle_subsidence is True
@@ -702,7 +732,7 @@ class init_tools(abc.ABC):
 
             self.sigma = self.subsidence_mask * self._subsidence_rate * self.dt
 
-    def init_metadata_list(self):
+    def init_metadata_list(self) -> None:
         """Populate the list of metadata information.
 
         Sets up the dictionary object for the standard metadata.
@@ -739,7 +769,7 @@ class init_tools(abc.ABC):
                                              'f4',
                                              (self._netcdf_coords[0])]
 
-    def load_checkpoint(self, defer_output=False):
+    def load_checkpoint(self, defer_output: bool = False) -> None:
         """Load the checkpoint from the .npz file.
 
         Uses the file at the path determined by `self.prefix` and a file named
@@ -751,7 +781,7 @@ class init_tools(abc.ABC):
 
         As a standard user, you should not need to worry about any of these
         pathways or options. However, if you are developing pyDeltaRCM or
-        customizing the model in any way that involves loadind from
+        customizing the model in any way that involves loading from
         checkpoints, you should be aware of these pathways.
 
         For example, loading from checkpoint will succeed if no netCDF4 file
@@ -761,7 +791,7 @@ class init_tools(abc.ABC):
 
         .. important::
 
-            If you are customing the model and intend to use checkpointing and
+            If you are customizing the model and intend to use checkpointing and
             the :obj:`Preprocessor` parallel infrastructure, be sure that
             parameter :obj:`defer_output` is `True` until the
             :obj:`load_checkpoint` method can be called from the thread the
