@@ -1,24 +1,22 @@
-import os
-import sys
-import argparse
 import abc
-import time
-import platform
-
+import argparse
 import itertools
-from pathlib import Path
-import warnings
-
 import multiprocessing
-
+import os
+import platform
+import time
+import warnings
 import yaml
+from pathlib import Path
+from typing import Dict, Optional, Type, List, Union
+
 import numpy as np
 
 from . import shared_tools
 from .model import DeltaModel as BaseDeltaModel
 
 
-_ver = ' '.join(('pyDeltaRCM', shared_tools._get_version()))
+_ver: str = ' '.join(('pyDeltaRCM', shared_tools._get_version()))
 
 
 class BasePreprocessor(abc.ABC):
@@ -36,7 +34,7 @@ class BasePreprocessor(abc.ABC):
         out the Python API.
 
     """
-    def __init__(self):
+    def __init__(self) -> None:
         """Initialize the base preprocessor.
         """
         self._input_file = None  # initialize empty
@@ -45,16 +43,16 @@ class BasePreprocessor(abc.ABC):
         self._has_set = False
         self._has_matrix = False
 
-        self._file_list = []    # list of yaml files for jobs
-        self._config_list = []  # list of dict configs for jobs
-        self._job_list = []     # list of _Job objects
+        self._file_list: List[Path] = []    # list of yaml files for jobs
+        self._config_list = []              # list of dict configs for jobs
+        self._job_list = []                 # list of _Job objects
 
         self._dryrun = False
 
         self._is_completed = False
 
     @property
-    def file_list(self):
+    def file_list(self) -> List[Path]:
         """File list.
 
         A list of `Path` to input YAML files for jobs constructed by the
@@ -84,7 +82,7 @@ class BasePreprocessor(abc.ABC):
         """
         return self._job_list
 
-    def open_input_file_to_dict(self, input_file):
+    def open_input_file_to_dict(self, input_file: Union[str, Path]):
         """Open an input file and convert it to a dictionary.
 
         This method is used by subclassing Preprocessors to complete the first
@@ -115,7 +113,7 @@ class BasePreprocessor(abc.ABC):
 
         return yaml_dict
 
-    def construct_file_list(self):
+    def construct_file_list(self) -> None:
         """Construct the file list.
 
         The job list is constructed by expanding the various multi-job
@@ -146,7 +144,7 @@ class BasePreprocessor(abc.ABC):
         if self._has_ensemble or self._has_set or self._has_matrix:
             self._write_job_configs()
 
-    def _prelim_config_parsing(self):
+    def _prelim_config_parsing(self) -> None:
         """Preliminary configuration parsing.
 
         Extract ``.yml`` file (``self.input_file``) into a dictionary, if
@@ -209,7 +207,7 @@ class BasePreprocessor(abc.ABC):
             user_file.close()
             return yaml_dict
 
-    def _prepare_multijob_output(self):
+    def _prepare_multijob_output(self) -> None:
         if 'out_dir' not in self.config_dict.keys():
             raise ValueError(
                 'You must specify "out_dir" in YAML to use any '
@@ -229,7 +227,7 @@ class BasePreprocessor(abc.ABC):
         else:
             p.mkdir()
 
-    def _expand_ensemble(self):
+    def _expand_ensemble(self) -> None:
         """Create ensemble random seeds and put into matrix.
 
         Ensemble expansion is implemented as a special class of matrix/set
@@ -323,7 +321,7 @@ class BasePreprocessor(abc.ABC):
             # change the variable to expand matrix on future step
             self._has_matrix = True
 
-    def _expand_set(self):
+    def _expand_set(self) -> None:
 
         # determine the set
         _set = self.config_dict.pop('set')
@@ -401,7 +399,7 @@ class BasePreprocessor(abc.ABC):
                    fmt='%s', delimiter=',', comments='',
                    header=self._matrix_table_header)
 
-    def _expand_matrix(self):
+    def _expand_matrix(self) -> None:
         """Expand YAML matrix.
 
         Compute the matrix expansion of parameters listed in `matrix` key.
@@ -490,11 +488,15 @@ class BasePreprocessor(abc.ABC):
                    fmt='%s', delimiter=',', comments='',
                    header=self._matrix_table_header)
 
-    def _write_job_configs(self):
+    def _write_job_configs(self) -> None:
 
         if len(self._config_list) == 0:
             raise ValueError('Config list empty!')
 
+        # do not write any time information to file
+        #   this list defines the time-related keywords
+        _time_list = ['timesteps', 'time', 'time_years']
+
         # loop through each job to write out info
         for c, config in enumerate(self.config_list):
 
@@ -503,7 +505,10 @@ class BasePreprocessor(abc.ABC):
             if self.verbose > 0:
                 print('Writing YAML file for job ' + str(int(c)))
 
-            # ith_config = config['config']
+            # strip the time related parameters from the config
+            config_write = config.copy()
+            [config_write.pop(key) for key in _time_list if key in config_write.keys()]
+
             ith_dir = Path(config['out_dir'])       # job output folder
             ith_id = ith_dir.parts[-1]              # job id
 
@@ -520,12 +525,12 @@ class BasePreprocessor(abc.ABC):
 
             # write the file into the output directory
             ith_p = ith_dir / (str(ith_id) + '.yml')
-            _write_yaml_config_to_file(config, ith_p)
+            _write_yaml_config_to_file(config_write, ith_p)
 
             # append to the file list
             self._file_list.append(ith_p)
 
-    def run_jobs(self, DeltaModel=None):
+    def run_jobs(self, DeltaModel=None) -> None:
         """Run the set of jobs.
 
         This method can be seen as the actual execution stage of the
@@ -667,7 +672,8 @@ class _BaseJob(abc.ABC):
     """
 
     def __init__(self, i, input_file, config_dict,
-                 DeltaModel=None, defer_output=False):
+                 DeltaModel: Optional[Type[BaseDeltaModel]]=None, 
+                 defer_output: bool=False) -> None:
         """Initialize a job.
 
         The `input_file` argument is passed to the DeltaModel for
@@ -681,10 +687,6 @@ class _BaseJob(abc.ABC):
         self.i = i
         self.input_file = input_file
 
-        # if 'DeltaModel' in config_dict.keys():
-        #     _DM = config_dict['DeltaModel']
-        # else:
-        #     _DM = DeltaModel
         if (DeltaModel is None):
             DeltaModel = BaseDeltaModel
 
@@ -751,7 +753,7 @@ class _SerialJob(_BaseJob):
     .. note:: You probably don't need to interact with this class directly.
     """
 
-    def __init__(self, i, input_file, config_dict, DeltaModel=None,):
+    def __init__(self, i, input_file, config_dict, DeltaModel=None) -> None:
         """Initialize a serial job.
 
         The `input_file` argument is passed to the DeltaModel for
@@ -762,9 +764,10 @@ class _SerialJob(_BaseJob):
         run time.
         """
         super().__init__(i, input_file, config_dict,
-                         DeltaModel=DeltaModel, defer_output=False)
+                         DeltaModel=DeltaModel,
+                         defer_output=False)
 
-    def run(self):
+    def run(self) -> None:
         """Loop the model.
 
         Iterate the timestep ``update`` routine for the specified number of
@@ -817,7 +820,7 @@ class _ParallelJob(_BaseJob, multiprocessing.Process):
     """
 
     def __init__(self, i, queue, sema,
-                 input_file, config_dict, DeltaModel=None):
+                 input_file, config_dict, DeltaModel=None) -> None:
         """Initialize a parallel job.
 
         The `input_file` argument is passed to the DeltaModel for
@@ -829,13 +832,14 @@ class _ParallelJob(_BaseJob, multiprocessing.Process):
         """
         # inherit with explicit method resolution order
         _BaseJob.__init__(self, i, input_file, config_dict,
-                          DeltaModel=DeltaModel, defer_output=True)
+                          DeltaModel=DeltaModel,
+                          defer_output=True)
         multiprocessing.Process.__init__(self)
 
         self.queue = queue
         self.sema = sema  # semaphore for limited multiprocessing
 
-    def run(self):
+    def run(self) -> None:
         """Run the model, with infrastructure for parallel.
 
         Iterate the timestep ``update`` routine for the specified number of
@@ -922,7 +926,7 @@ class PreprocessorCLI(BasePreprocessor):
 
     """
 
-    def __init__(self):
+    def __init__(self) -> None:
         """Initialize the CLI preprocessor.
 
         The initialization includes the entire configuration of the job list
@@ -950,7 +954,7 @@ class PreprocessorCLI(BasePreprocessor):
         # construct file list (expansions)
         self.construct_file_list()
 
-    def process_arguments(self):
+    def process_arguments(self) -> Union[Dict[str, float], Dict[str, int]]:
         """Process the command line arguments.
 
         .. note::
@@ -1053,7 +1057,7 @@ class Preprocessor(BasePreprocessor):
 
     """
 
-    def __init__(self, input_file=None, **kwargs):
+    def __init__(self, input_file=None, **kwargs) -> None:
         """Initialize the python preprocessor.
 
         The initialization includes the entire configuration of the job list
@@ -1100,7 +1104,7 @@ class Preprocessor(BasePreprocessor):
         self.construct_file_list()
 
 
-def preprocessor_wrapper():
+def preprocessor_wrapper() -> None:
     """Wrapper for command line interface.
 
     The `entry_points` setup of a command line interface requires a function,
@@ -1120,10 +1124,10 @@ def preprocessor_wrapper():
     pp.run_jobs()
 
 
-def _write_yaml_config_to_file(_config, _path):
+def _write_yaml_config_to_file(_config, _path) -> None:
     """Write a config to file in output folder.
 
-    Write the entire yaml configuation for the configured job out to a
+    Write the entire yaml configuration for the configured job out to a
     file in the job output foler.
 
     .. note::
@@ -1144,7 +1148,7 @@ def _write_yaml_config_to_file(_config, _path):
     f.close()
 
 
-def scale_relative_sea_level_rise_rate(mmyr, If=1):
+def scale_relative_sea_level_rise_rate(mmyr: float, If: float = 1) -> float:
     """Scale a relative sea level rise rate to model time.
 
     This function scales any relative sea level rise rate (RSLR) (e.g., sea
