@@ -1,10 +1,11 @@
+import abc
+from typing import Any, Tuple
 
 import numpy as np
 from numba import njit
 from numba import float32, int64
 from numba.experimental import jitclass
 from scipy import ndimage
-import abc
 
 import warnings
 
@@ -15,7 +16,7 @@ from . import shared_tools
 
 class sed_tools(abc.ABC):
 
-    def route_sediment(self):
+    def route_sediment(self) -> None:
         """Sediment routing main method.
 
         This is the main method for sediment routing in the model. It is
@@ -48,7 +49,7 @@ class sed_tools(abc.ABC):
         self.hook_route_all_mud_parcels()
         self.route_all_mud_parcels()
 
-    def sed_route(self):
+    def sed_route(self) -> None:
         """Deprecated, since v1.3.1. Use :obj:`route_sediment`."""
         _msg = ('`sed_route` and `hook_sed_route` are deprecated and '
                 'have been replaced with `route_sediment`. '
@@ -58,7 +59,7 @@ class sed_tools(abc.ABC):
         warnings.warn(UserWarning(_msg))
         self.route_sediment()
 
-    def init_sediment_iteration(self):
+    def init_sediment_iteration(self) -> None:
         """Init the water iteration routine.
 
         Clear and pad fields in preparation for iterating parcels.
@@ -74,7 +75,7 @@ class sed_tools(abc.ABC):
         self.Vp_dep_sand[:] = 0
         self.Vp_dep_mud[:] = 0
 
-    def get_inlet_weights_sediment(self, **kwargs):
+    def get_inlet_weights_sediment(self, **kwargs: Any):
         """Get weight for inlet cells for sediment parcels.
 
         This method determines the *weights* describing which inlet cells
@@ -91,7 +92,7 @@ class sed_tools(abc.ABC):
         """
         return shared_tools.get_inlet_weights(self.inlet)
 
-    def route_all_sand_parcels(self):
+    def route_all_sand_parcels(self) -> None:
         """Route sand parcels; topo diffusion.
 
         This method largely wraps the :obj:`SandRouter`. First, the number of
@@ -128,7 +129,7 @@ class sed_tools(abc.ABC):
         self._sr.run(start_indices, self.eta, self.stage, self.depth,
                      self.cell_type, self.uw, self.ux, self.uy,
                      self.Vp_dep_mud, self.Vp_dep_sand,
-                     self.qw, self.qx, self.qy, self.qs)
+                     self.qw, self.qx, self.qy, self.qs, self.mod_sed_weight)
 
         # These are the variables updated at the end of the `SandRouter`. If
         # you attempt to drop in a replacement SandRouter, you will need to
@@ -146,7 +147,7 @@ class sed_tools(abc.ABC):
         self.uy = self._sr.uy  # update component flow fielda
         self.qs = self._sr.qs
 
-    def route_all_mud_parcels(self):
+    def route_all_mud_parcels(self) -> None:
         """Route mud parcels.
 
         This method largely wraps the :obj:`MudRouter`. First, the number of
@@ -183,7 +184,7 @@ class sed_tools(abc.ABC):
         self._mr.run(start_indices, self.eta, self.stage, self.depth,
                      self.cell_type, self.uw, self.ux, self.uy,
                      self.Vp_dep_mud, self.Vp_dep_sand,
-                     self.qw, self.qx, self.qy)
+                     self.qw, self.qx, self.qy, self.mod_sed_weight)
 
         # These are the variables updated at the end of the `MudRouter`. If
         # you attempt to drop in a replacement MudRouter, you will need to
@@ -200,7 +201,7 @@ class sed_tools(abc.ABC):
         self.ux = self._mr.ux  # update component flow field
         self.uy = self._mr.uy  # update component flow field
 
-    def topo_diffusion(self):
+    def topo_diffusion(self) -> None:
         """Diffuse topography after routing.
 
         Diffuse topography after routing all coarse sediment parcels. The
@@ -224,7 +225,8 @@ class sed_tools(abc.ABC):
 
 @njit
 def _get_weight_at_cell_sediment(ind, weight_int, depth_nbrs, ct_nbrs,
-                                 dry_depth, theta, distances_flat):
+                                 dry_depth: float, theta: float,
+                                 distances_flat: int, mod_sed_weight):
     """Get neighbor weight array for sediment routing.
 
     .. todo::
@@ -241,7 +243,7 @@ def _get_weight_at_cell_sediment(ind, weight_int, depth_nbrs, ct_nbrs,
     weight_int[ctr] = 0
 
     weight = np.copy(weight_int)  # no gamma weighting here
-    weight = (depth_nbrs ** theta) * weight
+    weight = ((depth_nbrs * mod_sed_weight) ** theta) * weight
 
     # ALWAYS disallow the choice to not move
     weight[ctr] = 0
@@ -297,10 +299,12 @@ r_spec = [('_dt', float32), ('_dx', float32),
           ('Vp_res', float32), ('Vp_dep_mud', float32[:, :]),
           ('Vp_dep_sand', float32[:, :]),
           ('U_dep_mud', float32), ('U_ero_mud', float32),
-          ('U_ero_sand', float32)]
+          ('U_ero_sand', float32), ('mod_erosion', float32[:, :]),
+          ('mod_sed_weight', float32[:, :]),
+          ('pad_mod_sed_weight', float32[:, :])]
 
 
-class BaseRouter(object):
+class BaseRouter:
     """BaseRouter.
 
     Defines common methods for jitted routers.
@@ -319,14 +323,14 @@ class BaseRouter(object):
         `Router`.
     """
     @abc.abstractmethod
-    def run(self, *args, **kwargs):
+    def run(self, *args: Any, **kwargs: Any):
         ...
 
     @abc.abstractmethod
     def _route_one_parcel(self):
         ...
 
-    def _choose_next_location(self, px, py):
+    def _choose_next_location(self, px: int, py: int) -> Tuple[int, int, float]:
 
         # choose next location with weights
         stage_nbrs = self.pad_stage[
@@ -335,6 +339,8 @@ class BaseRouter(object):
             px:px + 3, py:py + 3]
         cell_type_ind = self.pad_cell_type[
             px:px + 3, py:py + 3]
+        sed_weight_nbrs = self.pad_mod_sed_weight[
+            px:px + 3, py:py + 3]
 
         _, weight_int = shared_tools.get_weight_sfc_int(
             self.stage[px, py], stage_nbrs.ravel(), self.qx[px, py],
@@ -349,7 +355,8 @@ class BaseRouter(object):
 
         weights = _get_weight_at_cell_sediment(
             (px, py), weight_int, depth_nbrs.ravel(),
-            cell_type_ind.ravel(), self.dry_depth, self.theta_sed, self.distances_flat)
+            cell_type_ind.ravel(), self.dry_depth, self.theta_sed,
+            self.distances_flat, sed_weight_nbrs.ravel())
 
         new_cell = shared_tools.random_pick(weights)
 
@@ -359,7 +366,7 @@ class BaseRouter(object):
         return istep, jstep, dist
 
     @abc.abstractmethod
-    def _deposit_or_erode(self, px, py):
+    def _deposit_or_erode(self, px: int, py: int):
         """Determine whether to erode or deposit.
 
         This is the decision making component of the routine, and will be
@@ -367,7 +374,7 @@ class BaseRouter(object):
         """
         ...
 
-    def _update_fields(self, Vp_change, px, py):
+    def _update_fields(self, Vp_change: float, px: int, py: int) -> None:
         """Execute deposit of sand or mud.
 
         Deposit sediment volume `Vp_change`. The change in bed elevation
@@ -434,7 +441,9 @@ class BaseRouter(object):
             self.ux[px, py] = 0
             self.uy[px, py] = 0
 
-    def _compute_Vp_ero(self, Vp_sed, U_loc, U_ero, beta):
+    def _compute_Vp_ero(self, Vp_sed: float, U_loc: float,
+                        U_ero: float, beta: float,
+                        mod_erosion: float) -> float:
         """Compute volume erorded based on velocity.
 
         The volume of sediment eroded depends on the local flow velocity
@@ -458,15 +467,18 @@ class BaseRouter(object):
         beta : :obj:`float`
             unknown.
 
+        mod_erosion : :obj:`float`
+            Local linear modifier for erosion.
+
         Returns
         -------
         Vp_ero : :obj:`float`
             Volume of eroded sediment.
         """
-        return (Vp_sed * (U_loc**beta - U_ero**beta) /
+        return (mod_erosion * Vp_sed * (U_loc**beta - U_ero**beta) /
                 U_ero**beta)
 
-    def _limit_Vp_change(self, Vp, stage, eta, dx, dep_ero):
+    def _limit_Vp_change(self, Vp, stage, eta, dx: float, dep_ero: int):
         """Limit change in volume to 1/4 of a cell volume.
 
         Function is used by multiple pathways in `mud_dep_ero` and `sand_dep_ero`
@@ -503,9 +515,10 @@ class SandRouter(BaseRouter):
         :obj:`~pyDeltaRCM.init_tools.init_tools.init_sediment_routers` in any
         property `setter`.
     """
-    def __init__(self, _dt, dx, Vp_sed, u_max, qs0, u0, U_ero_sand, f_bedload,
-                 ivec_flat, jvec_flat, iwalk_flat, jwalk_flat, distances_flat,
-                 dry_depth, beta, stepmax, theta_sed):
+    def __init__(self, _dt: float, dx: float, Vp_sed, u_max: float, qs0: float,
+                 u0, U_ero_sand, f_bedload, ivec_flat, jvec_flat, iwalk_flat,
+                 jwalk_flat, distances_flat, dry_depth: float, beta: float,
+                 stepmax, theta_sed: float, mod_erosion) -> None:
 
         self._dt = _dt
         self._dx = dx
@@ -525,10 +538,11 @@ class SandRouter(BaseRouter):
         self._beta = beta
         self.stepmax = stepmax
         self.theta_sed = theta_sed
+        self.mod_erosion = mod_erosion
 
-    def run(self, start_indices, eta, stage, depth, cell_type,
+    def run(self, start_indices: np.ndarray, eta, stage, depth, cell_type,
             uw, ux, uy, Vp_dep_mud, Vp_dep_sand,
-            qw, qx, qy, qs):
+            qw, qx, qy, qs, mod_sed_weight) -> None:
         """The main function to route and deposit/erode sand parcels.
 
         Algorithm is to:
@@ -569,6 +583,7 @@ class SandRouter(BaseRouter):
         self.pad_stage = shared_tools.custom_pad(stage)
         self.pad_depth = shared_tools.custom_pad(depth)
         self.pad_cell_type = shared_tools.custom_pad(cell_type)
+        self.pad_mod_sed_weight = shared_tools.custom_pad(mod_sed_weight)
         self.Vp_dep_mud = Vp_dep_mud
         self.Vp_dep_sand = Vp_dep_sand
         self.qw = qw
@@ -588,7 +603,7 @@ class SandRouter(BaseRouter):
                                self.Vp_res / 2. / self._dt / self._dx)
             self._route_one_parcel(px, py)
 
-    def _route_one_parcel(self, px, py):
+    def _route_one_parcel(self, px: int, py: int) -> None:
         """Route one parcel.
 
         Algorithm is to:
@@ -639,7 +654,7 @@ class SandRouter(BaseRouter):
             if (it == self.stepmax):
                 sed_continue = False
 
-    def _partition_sediment(self, px0, py0, px, py, dist):
+    def _partition_sediment(self, px0: int, py0: int, px: int, py: int, dist: float) -> None:
         """Spread sediment flux between two cells.
         """
         partition = self.Vp_res / 2. / self._dt / self._dx
@@ -647,7 +662,7 @@ class SandRouter(BaseRouter):
             self.qs[px0, py0] += partition  # deposition in current cell
             self.qs[px, py] += partition  # deposition in new cell
 
-    def _deposit_or_erode(self, px, py):
+    def _deposit_or_erode(self, px: int, py: int) -> None:
         """Decide if deposit or erode sand.
 
         .. note:: Volumetric change is limited to 1/4 local cell water volume.
@@ -666,6 +681,7 @@ class SandRouter(BaseRouter):
         qs_cap = (self.qs0 * self._f_bedload / self._u0**self._beta *
                   U_loc**self._beta)
         qs_loc = self.qs[px, py]
+        ero_mod_loc = self.mod_erosion[px, py]
 
         Vp_change = 0
         if qs_loc > qs_cap:
@@ -682,7 +698,8 @@ class SandRouter(BaseRouter):
             #     critical erosion threshold for sand, *and* if the local
             #     transport capacity is not yet reached.
             Vp_change = self._compute_Vp_ero(self.Vp_sed, U_loc,
-                                             self.U_ero_sand, self._beta)
+                                             self.U_ero_sand, self._beta,
+                                             ero_mod_loc)
             Vp_change = self._limit_Vp_change(Vp_change, self.stage[px, py],
                                               self.eta[px, py], self._dx, 1)
             Vp_change = Vp_change * -1
@@ -712,9 +729,10 @@ class MudRouter(BaseRouter):
         :obj:`~pyDeltaRCM.init_tools.init_tools.init_sediment_routers` in any
         property `setter`.
     """
-    def __init__(self, _dt, dx, Vp_sed, u_max, U_dep_mud, U_ero_mud,
+    def __init__(self, _dt: float, dx: float, Vp_sed, u_max: float, U_dep_mud: float, U_ero_mud: float,
                  ivec_flat, jvec_flat, iwalk_flat, jwalk_flat, distances_flat,
-                 dry_depth, _lambda, beta, stepmax, theta_sed):
+                 dry_depth: float, _lambda, beta: float, stepmax,
+                 theta_sed: float, mod_erosion) -> None:
 
         self._dt = _dt
         self._dx = dx
@@ -733,10 +751,11 @@ class MudRouter(BaseRouter):
         self._beta = beta
         self.stepmax = stepmax
         self.theta_sed = theta_sed
+        self.mod_erosion = mod_erosion
 
     def run(self, start_indices, eta, stage, depth, cell_type,
             uw, ux, uy, Vp_dep_mud, Vp_dep_sand,
-            qw, qx, qy):
+            qw, qx, qy, mod_sed_weight) -> None:
         """The main function to route and deposit/erode mud parcels.
 
         """
@@ -751,6 +770,7 @@ class MudRouter(BaseRouter):
         self.pad_stage = shared_tools.custom_pad(stage)
         self.pad_depth = shared_tools.custom_pad(depth)
         self.pad_cell_type = shared_tools.custom_pad(cell_type)
+        self.pad_mod_sed_weight = shared_tools.custom_pad(mod_sed_weight)
         self.Vp_dep_mud = Vp_dep_mud
         self.Vp_dep_sand = Vp_dep_sand
         self.qw = qw
@@ -767,7 +787,7 @@ class MudRouter(BaseRouter):
 
             self._route_one_parcel(px, py)
 
-    def _route_one_parcel(self, px, py):
+    def _route_one_parcel(self, px: int, py: int) -> None:
         """Route one parcel.
 
         """
@@ -790,7 +810,7 @@ class MudRouter(BaseRouter):
             if (it == self.stepmax):
                 sed_continue = False
 
-    def _deposit_or_erode(self, px, py):
+    def _deposit_or_erode(self, px: int, py: int) -> None:
         """Decide if deposit or erode mud.
 
         .. note:: Volumetric change is limited to 1/4 local cell water volume.
@@ -798,6 +818,7 @@ class MudRouter(BaseRouter):
         .. important:: TODO: complete description specific for mud transport
         """
         U_loc = self.uw[px, py]
+        ero_mod_loc = self.mod_erosion[px, py]
 
         Vp_change = 0
         if U_loc < self.U_dep_mud:
@@ -809,7 +830,8 @@ class MudRouter(BaseRouter):
 
         if U_loc > self.U_ero_mud:
             Vp_change = self._compute_Vp_ero(self.Vp_sed, U_loc,
-                                             self.U_ero_mud, self._beta)
+                                             self.U_ero_mud, self._beta,
+                                             ero_mod_loc)
             Vp_change = self._limit_Vp_change(Vp_change, self.stage[px, py],
                                               self.eta[px, py], self._dx, 1)
             Vp_change = Vp_change * -1
