@@ -1,17 +1,18 @@
 import glob
 import os
+import unittest.mock as mock
+from pathlib import Path
+
 import netCDF4
 import numpy as np
 
-import unittest.mock as mock
-
 from pyDeltaRCM.model import DeltaModel
 from .. import utilities
 
 
 class TestTimingOutputData:
 
-    def test_update_make_record(self, tmp_path):
+    def test_update_make_record(self, tmp_path: Path) -> None:
         # create a delta with default settings
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml',
                                      {'save_checkpoint': True})
@@ -85,7 +86,7 @@ class TestTimingOutputData:
         assert _delta.save_iter == int(2)
         assert _delta._save_time_since_checkpoint == _delta._dt
 
-    def test_update_saving_intervals_on_cycle(self, tmp_path):
+    def test_update_saving_intervals_on_cycle(self, tmp_path: Path) -> None:
         """dt == 300; save_dt == 600"""
         # create a delta with default settings
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml')
@@ -137,7 +138,7 @@ class TestTimingOutputData:
         assert _delta.time == 3000
         assert _delta._is_finalized is False
 
-    def test_update_saving_intervals_short(self, tmp_path):
+    def test_update_saving_intervals_short(self, tmp_path: Path) -> None:
         """dt == 300; save_dt == 100"""
         # create a delta with default settings
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml')
@@ -181,7 +182,7 @@ class TestTimingOutputData:
         assert _delta.save_iter == 4  # once during init
         assert _delta.time == 900
 
-    def test_update_saving_intervals_offset_long_not_double(self, tmp_path):
+    def test_update_saving_intervals_offset_long_not_double(self, tmp_path: Path) -> None:
         """dt == 300; save_dt == 500"""
         # create a delta with default settings
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml')
@@ -222,7 +223,7 @@ class TestTimingOutputData:
         assert _delta.time == 3600
         assert _delta.save_grids_and_figs.call_count == 6
 
-    def test_update_saving_intervals_offset_long_over_double(self, tmp_path):
+    def test_update_saving_intervals_offset_long_over_double(self, tmp_path: Path) -> None:
         """dt == 300; save_dt == 1000"""
         # create a delta with default settings
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml')
@@ -278,7 +279,7 @@ class TestTimingOutputData:
         assert _delta.save_grids_and_figs.call_count == 9
         assert _delta._is_finalized is False
 
-    def test_finalize_updated(self, tmp_path):
+    def test_finalize_updated(self, tmp_path: Path) -> None:
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml')
         _delta = DeltaModel(input_file=p)
 
@@ -309,10 +310,9 @@ class TestTimingOutputData:
 
         assert _delta._is_finalized is True
 
-    def test_save_one_fig_no_grids(self, tmp_path):
+    def test_save_one_fig_no_grids(self, tmp_path: Path) -> None:
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml',
                                      {'save_dt': 1,
-                                      'save_strata': False,
                                       'save_eta_figs': True})
         _delta = DeltaModel(input_file=p)
 
@@ -349,7 +349,7 @@ class TestTimingOutputData:
         assert os.path.isfile(exp_path_png2)
         assert not os.path.isfile(exp_path_png3)
 
-    def test_save_one_fig_one_grid(self, tmp_path):
+    def test_save_one_fig_one_grid(self, tmp_path: Path) -> None:
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml',
                                      {'save_dt': 1,
                                       'save_eta_grids': True,
@@ -384,7 +384,7 @@ class TestTimingOutputData:
         assert nc_size_after == nc_size_middle
         assert nc_size_after > nc_size_before
 
-    def test_save_metadata_no_grids(self, tmp_path):
+    def test_save_metadata_no_grids(self, tmp_path: Path) -> None:
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml',
                                      {'save_dt': 1,
                                       'save_metadata': True})
@@ -414,7 +414,7 @@ class TestTimingOutputData:
         assert ds['meta']['H_SL'].shape[0] == 3
         assert ds['meta']['L0'][:] == 3
 
-    def test_save_subsidence_metadata_no_grids(self, tmp_path):
+    def test_save_subsidence_metadata_no_grids(self, tmp_path: Path) -> None:
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml',
                                      {'save_dt': 1,
                                       'toggle_subsidence': True,
@@ -450,7 +450,7 @@ class TestTimingOutputData:
         assert np.all(ds['meta']['sigma'] == _delta.sigma)
         assert ds['meta']['start_subsidence'][:] == 0
 
-    def test_save_one_grid_metadata_by_default(self, tmp_path):
+    def test_save_one_grid_metadata_by_default(self, tmp_path: Path) -> None:
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml',
                                      {'save_dt': 1,
                                       'save_metadata': False,
