@@ -1,5 +1,7 @@
 import os
+import sys
 import glob
+from pathlib import Path
 
 import unittest.mock as mock
 
@@ -10,7 +12,7 @@ from . import utilities
 
 class TestLogModelTime:
 
-    def test_records_arbitrary_time_values(self, tmp_path, capsys):
+    def test_records_arbitrary_time_values(self, tmp_path: Path, capsys) -> None:
         """
         This test should create the log, and then print nothing at all.
         """
@@ -32,7 +34,7 @@ class TestLogModelTime:
         _calls = [mock.call('Time: 3.1; timestep: 42')]
         _delta.logger.info.assert_has_calls(_calls)
 
-    def test_verbose_printing_0(self, tmp_path, capsys):
+    def test_verbose_printing_0(self, tmp_path: Path, capsys) -> None:
         """
         This test should create the log, and then print nothing at all.
         """
@@ -55,7 +57,7 @@ class TestLogModelTime:
         captd = capsys.readouterr()
         assert captd.out == ''
 
-    def test_verbose_printing_1(self, tmp_path, capsys):
+    def test_verbose_printing_1(self, tmp_path: Path, capsys) -> None:
         """
         This test should create the log, and then print nothing at all.
         """
@@ -78,7 +80,7 @@ class TestLogModelTime:
         captd = capsys.readouterr()
         assert 'Time: 0.0' in captd.out  # if verbose >= 1
 
-    def test_verbose_printing_2(self, tmp_path, capsys):
+    def test_verbose_printing_2(self, tmp_path: Path, capsys) -> None:
         """
         This test should create the log, and then print nothing at all.
         """
@@ -109,7 +111,7 @@ class TestLoggerIntegratedDuringInitialization:
     instantiation of the DeltaModel...
     """
 
-    def test_logger_has_initialization_lines(self, tmp_path):
+    def test_logger_has_initialization_lines(self, tmp_path: Path) -> None:
         file_name = 'user_parameters.yaml'
         p, f = utilities.create_temporary_file(tmp_path, file_name)
         utilities.write_parameter_to_file(f, 'out_dir', tmp_path / 'out_dir')
@@ -128,12 +130,24 @@ class TestLoggerIntegratedDuringInitialization:
             assert 'Creating model domain' in _lines
             assert 'Initializing output NetCDF4 file' in _lines
             assert 'Model initialization complete' in _lines
+
+            if sys.platform.startswith('linux'):
+                assert 'Platform: Linux-' in _lines
+            elif sys.platform == 'darwin':
+                guess1 = 'Platform: Darwin-' in _lines
+                guess2 = 'Platform: macOS-' in _lines
+                assert (guess1 | guess2)
+            elif sys.platform.startswith('win'):
+                assert 'Platform: Windows-' in _lines
+            else:
+                raise RuntimeError(
+                    'Platform type not recognized.')
         assert not os.path.isfile(os.path.join(
             tmp_path, 'out_dir', 'discharge_0.0.png'))
         assert not os.path.isfile(os.path.join(
             tmp_path, 'out_dir', 'eta_0.0.png'))
 
-    def test_logger_random_seed_always_recorded(self, tmp_path):
+    def test_logger_random_seed_always_recorded(self, tmp_path: Path) -> None:
         file_name = 'user_parameters.yaml'
         p, f = utilities.create_temporary_file(tmp_path, file_name)
         utilities.write_parameter_to_file(f, 'out_dir', tmp_path / 'out_dir')
