@@ -3,6 +3,7 @@
 import numpy as np
 
 import pytest
+from pathlib import Path
 
 import unittest.mock as mock
 
@@ -13,7 +14,7 @@ from . import utilities
 
 class Test__init__:
 
-    def test_init(self, tmp_path):
+    def test_init(self, tmp_path: Path) -> None:
         """
         test the deltaRCM_driver init (happened when delta.initialize was run)
         """
@@ -26,11 +27,11 @@ class Test__init__:
         # check that subclass parameter dictionary has been initialized
         assert _delta.subclass_parameters == {}
 
-    def test_error_if_no_file_found(self):
+    def test_error_if_no_file_found(self) -> None:
         with pytest.raises(FileNotFoundError):
             _ = DeltaModel(input_file='./nonexisting_file.yaml')
 
-    def test_override_single_default(self, tmp_path):
+    def test_override_single_default(self, tmp_path: Path) -> None:
         file_name = 'user_parameters.yaml'
         p, f = utilities.create_temporary_file(tmp_path, file_name)
         utilities.write_parameter_to_file(f, 'out_dir', tmp_path / 'out_dir')
@@ -39,7 +40,7 @@ class Test__init__:
         delta = DeltaModel(input_file=p)
         assert delta.S0 == 0.005
 
-    def test_override_two_defaults(self, tmp_path):
+    def test_override_two_defaults(self, tmp_path: Path) -> None:
         file_name = 'user_parameters.yaml'
         p, f = utilities.create_temporary_file(tmp_path, file_name)
         utilities.write_parameter_to_file(f, 'out_dir', tmp_path / 'out_dir')
@@ -50,12 +51,12 @@ class Test__init__:
         assert delta.S0 == 0.005
         assert delta.Np_sed == 2
 
-    def test_override_single_default_kwarg(self, tmp_path):
+    def test_override_single_default_kwarg(self, tmp_path: Path) -> None:
         _out_dir = str(tmp_path / 'out_dir')
         delta = DeltaModel(out_dir=_out_dir, S0=0.005)
         assert delta.S0 == 0.005
 
-    def test_override_two_defaults_kwargs(self, tmp_path):
+    def test_override_two_defaults_kwargs(self, tmp_path: Path) -> None:
         _out_dir = str(tmp_path / 'out_dir')
         delta = DeltaModel(
             out_dir=_out_dir,
@@ -64,7 +65,7 @@ class Test__init__:
         assert delta.S0 == 0.005
         assert delta.Np_sed == 2
 
-    def test_override_yaml_with_kwarg(self, tmp_path):
+    def test_override_yaml_with_kwarg(self, tmp_path: Path) -> None:
         file_name = 'user_parameters.yaml'
         p, f = utilities.create_temporary_file(tmp_path, file_name)
         utilities.write_parameter_to_file(f, 'out_dir', tmp_path / 'out_dir')
@@ -74,7 +75,7 @@ class Test__init__:
             delta = DeltaModel(input_file=p, S0=0.0333)
         assert delta.S0 == 0.0333
 
-    def test_override_bad_type_float_string(self, tmp_path):
+    def test_override_bad_type_float_string(self, tmp_path: Path) -> None:
         file_name = 'user_parameters.yaml'
         p, f = utilities.create_temporary_file(tmp_path, file_name)
         utilities.write_parameter_to_file(f, 'out_dir', tmp_path / 'out_dir')
@@ -83,7 +84,7 @@ class Test__init__:
         with pytest.raises(TypeError):
             _ = DeltaModel(input_file=p)
 
-    def test_override_bad_type_int_float(self, tmp_path):
+    def test_override_bad_type_int_float(self, tmp_path: Path) -> None:
         file_name = 'user_parameters.yaml'
         p, f = utilities.create_temporary_file(tmp_path, file_name)
         utilities.write_parameter_to_file(f, 'out_dir', tmp_path / 'out_dir')
@@ -92,28 +93,31 @@ class Test__init__:
         with pytest.raises(TypeError):
             _ = DeltaModel(input_file=p)
 
-    def test_not_creating_illegal_attributes(self, tmp_path):
+    def test_not_creating_illegal_attributes(self, tmp_path: Path) -> None:
         file_name = 'user_parameters.yaml'
         p, f = utilities.create_temporary_file(tmp_path, file_name)
         utilities.write_parameter_to_file(f, 'out_dir', tmp_path / 'out_dir')
         utilities.write_parameter_to_file(f, 'illegal_attribute', True)
         f.close()
-        delta = DeltaModel(input_file=p)
+        with pytest.warns(UserWarning, match=r'One or more .*illegal.*'):
+            delta = DeltaModel(input_file=p)
         assert delta.S0 == 0.00015  # from default.yaml
         assert not hasattr(delta, 'illegal_attribute')
 
-    def test_not_overwriting_existing_attributes(self, tmp_path):
+    def test_not_overwriting_existing_attributes(self, tmp_path: Path) -> None:
+        # this tests that you can't name something that already exists as a keyword name
         file_name = 'user_parameters.yaml'
         p, f = utilities.create_temporary_file(tmp_path, file_name)
         utilities.write_parameter_to_file(f, 'out_dir', tmp_path / 'out_dir')
         utilities.write_parameter_to_file(f, 'input_file', '/fake/path.yaml')
         f.close()
-        delta = DeltaModel(input_file=p)
+        with pytest.warns(UserWarning, match=r'One or more .*input_file.*'):
+            delta = DeltaModel(input_file=p)
         assert delta.S0 == 0.00015  # from default.yaml
         assert hasattr(delta, 'input_file')
         assert delta.input_file == p
 
-    def test_random_seed_settings_value(self, tmp_path):
+    def test_random_seed_settings_value(self, tmp_path: Path) -> None:
         file_name = 'user_parameters.yaml'
         p, f = utilities.create_temporary_file(tmp_path, file_name)
         utilities.write_parameter_to_file(f, 'seed', 9999)
@@ -129,7 +133,7 @@ class Test__init__:
         assert _preval_same == _postval_same
         assert delta.seed == 9999
 
-    def test_random_seed_settings_newinteger_default(self, tmp_path):
+    def test_random_seed_settings_newinteger_default(self, tmp_path: Path) -> None:
         file_name = 'user_parameters.yaml'
         p, f = utilities.create_temporary_file(tmp_path, file_name)
         utilities.write_parameter_to_file(f, 'out_dir', tmp_path / 'out_dir')
@@ -140,7 +144,7 @@ class Test__init__:
         assert delta.seed <= (2**32) - 1
         assert isinstance(int(delta.seed), int)
 
-    def test_negative_length(self, tmp_path):
+    def test_negative_length(self, tmp_path: Path) -> None:
         file_name = 'user_parameters.yaml'
         p, f = utilities.create_temporary_file(tmp_path, file_name)
         utilities.write_parameter_to_file(f, 'out_dir', tmp_path / 'out_dir')
@@ -149,7 +153,7 @@ class Test__init__:
         with pytest.raises(ValueError):
             _ = DeltaModel(input_file=p)
 
-    def test_negative_width(self, tmp_path):
+    def test_negative_width(self, tmp_path: Path) -> None:
         file_name = 'user_parameters.yaml'
         p, f = utilities.create_temporary_file(tmp_path, file_name)
         utilities.write_parameter_to_file(f, 'out_dir', tmp_path / 'out_dir')
@@ -158,7 +162,7 @@ class Test__init__:
         with pytest.raises(ValueError):
             _ = DeltaModel(input_file=p)
 
-    def test_negative_dx(self, tmp_path):
+    def test_negative_dx(self, tmp_path: Path) -> None:
         file_name = 'user_parameters.yaml'
         p, f = utilities.create_temporary_file(tmp_path, file_name)
         utilities.write_parameter_to_file(f, 'out_dir', tmp_path / 'out_dir')
@@ -167,7 +171,7 @@ class Test__init__:
         with pytest.raises(ValueError):
             _ = DeltaModel(input_file=p)
 
-    def test_bigger_than_Width_dx(self, tmp_path):
+    def test_bigger_than_Width_dx(self, tmp_path: Path) -> None:
         file_name = 'user_parameters.yaml'
         p, f = utilities.create_temporary_file(tmp_path, file_name)
         utilities.write_parameter_to_file(f, 'out_dir', tmp_path / 'out_dir')
@@ -177,7 +181,7 @@ class Test__init__:
         with pytest.raises(ValueError):
             _ = DeltaModel(input_file=p)
 
-    def test_bigger_than_Length_dx(self, tmp_path):
+    def test_bigger_than_Length_dx(self, tmp_path: Path) -> None:
         file_name = 'user_parameters.yaml'
         p, f = utilities.create_temporary_file(tmp_path, file_name)
         utilities.write_parameter_to_file(f, 'out_dir', tmp_path / 'out_dir')
@@ -187,7 +191,7 @@ class Test__init__:
         with pytest.raises(ValueError):
             _ = DeltaModel(input_file=p)
 
-    def test_negative_L0_meters(self, tmp_path):
+    def test_negative_L0_meters(self, tmp_path: Path) -> None:
         file_name = 'user_parameters.yaml'
         p, f = utilities.create_temporary_file(tmp_path, file_name)
         utilities.write_parameter_to_file(f, 'out_dir', tmp_path / 'out_dir')
@@ -196,7 +200,7 @@ class Test__init__:
         with pytest.raises(ValueError):
             _ = DeltaModel(input_file=p)
 
-    def test_negative_itermax(self, tmp_path):
+    def test_negative_itermax(self, tmp_path: Path) -> None:
         file_name = 'user_parameters.yaml'
         p, f = utilities.create_temporary_file(tmp_path, file_name)
         utilities.write_parameter_to_file(f, 'out_dir', tmp_path / 'out_dir')
@@ -205,7 +209,7 @@ class Test__init__:
         with pytest.raises(ValueError):
             _ = DeltaModel(input_file=p)
 
-    def test_negative_Np_water(self, tmp_path):
+    def test_negative_Np_water(self, tmp_path: Path) -> None:
         file_name = 'user_parameters.yaml'
         p, f = utilities.create_temporary_file(tmp_path, file_name)
         utilities.write_parameter_to_file(f, 'out_dir', tmp_path / 'out_dir')
@@ -214,7 +218,7 @@ class Test__init__:
         with pytest.raises(ValueError):
             _ = DeltaModel(input_file=p)
 
-    def test_negative_N0_meters(self, tmp_path):
+    def test_negative_N0_meters(self, tmp_path: Path) -> None:
         file_name = 'user_parameters.yaml'
         p, f = utilities.create_temporary_file(tmp_path, file_name)
         utilities.write_parameter_to_file(f, 'out_dir', tmp_path / 'out_dir')
@@ -223,7 +227,7 @@ class Test__init__:
         with pytest.raises(ValueError):
             _ = DeltaModel(input_file=p)
 
-    def test_negative_Np_sed(self, tmp_path):
+    def test_negative_Np_sed(self, tmp_path: Path) -> None:
         file_name = 'user_parameters.yaml'
         p, f = utilities.create_temporary_file(tmp_path, file_name)
         utilities.write_parameter_to_file(f, 'out_dir', tmp_path / 'out_dir')
@@ -232,7 +236,7 @@ class Test__init__:
         with pytest.raises(ValueError):
             _ = DeltaModel(input_file=p)
 
-    def test_negative_f_bedload(self, tmp_path):
+    def test_negative_f_bedload(self, tmp_path: Path) -> None:
         file_name = 'user_parameters.yaml'
         p, f = utilities.create_temporary_file(tmp_path, file_name)
         utilities.write_parameter_to_file(f, 'out_dir', tmp_path / 'out_dir')
@@ -241,7 +245,7 @@ class Test__init__:
         with pytest.raises(ValueError):
             _ = DeltaModel(input_file=p)
 
-    def test_big_f_bedload(self, tmp_path):
+    def test_big_f_bedload(self, tmp_path: Path) -> None:
         file_name = 'user_parameters.yaml'
         p, f = utilities.create_temporary_file(tmp_path, file_name)
         utilities.write_parameter_to_file(f, 'out_dir', tmp_path / 'out_dir')
@@ -250,7 +254,7 @@ class Test__init__:
         with pytest.raises(ValueError):
             _ = DeltaModel(input_file=p)
 
-    def test_negative_C0_percent(self, tmp_path):
+    def test_negative_C0_percent(self, tmp_path: Path) -> None:
         file_name = 'user_parameters.yaml'
         p, f = utilities.create_temporary_file(tmp_path, file_name)
         utilities.write_parameter_to_file(f, 'out_dir', tmp_path / 'out_dir')
@@ -259,7 +263,7 @@ class Test__init__:
         with pytest.raises(ValueError):
             _ = DeltaModel(input_file=p)
 
-    def test_negative_Csmooth(self, tmp_path):
+    def test_negative_Csmooth(self, tmp_path: Path) -> None:
         file_name = 'user_parameters.yaml'
         p, f = utilities.create_temporary_file(tmp_path, file_name)
         utilities.write_parameter_to_file(f, 'out_dir', tmp_path / 'out_dir')
@@ -268,13 +272,13 @@ class Test__init__:
         with pytest.raises(ValueError):
             _ = DeltaModel(input_file=p)
 
-    def test_negative_active_layer_thickness(self, tmp_path):
+    def test_negative_active_layer_thickness(self, tmp_path: Path) -> None:
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml',
                                      {'active_layer_thickness': -2.2})
         with pytest.raises(ValueError):
             _ = DeltaModel(input_file=p)
 
-    def test_badtype_figure_saving(self, tmp_path):
+    def test_badtype_figure_saving(self, tmp_path: Path) -> None:
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml')
         _model = DeltaModel(input_file=p, defer_output=True)
         # add request to plot invalid attribute
@@ -284,7 +288,7 @@ class Test__init__:
         with pytest.raises(AttributeError):
             _model.output_data()
 
-    def test_badshape_figure_saving(self, tmp_path):
+    def test_badshape_figure_saving(self, tmp_path: Path) -> None:
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml')
         _model = DeltaModel(input_file=p, defer_output=True)
         # add request to plot attribute w/ invalid shape
@@ -294,14 +298,14 @@ class Test__init__:
         with pytest.raises(AttributeError):
             _model.output_data()
 
-    def test_clobber_netcdf(self, tmp_path):
+    def test_clobber_netcdf(self, tmp_path: Path) -> None:
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml',
                                      {'clobber_netcdf': True})
         _model = DeltaModel(input_file=p)
         # assert that model could have clobbered a netcdf
         assert _model._clobber_netcdf is True
 
-    def test_clobbering(self, tmp_path):
+    def test_clobbering(self, tmp_path: Path) -> None:
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml',
                                      {'clobber_netcdf': True,
                                       'save_eta_grids': True})
@@ -315,7 +319,7 @@ class Test__init__:
         _model_2.output_netcdf.close()
         assert _model_2._clobber_netcdf is True
 
-    def test_no_clobber_error(self, tmp_path):
+    def test_no_clobber_error(self, tmp_path: Path) -> None:
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml',
                                      {'save_eta_grids': True})
         _model_1 = DeltaModel(input_file=p)
@@ -336,7 +340,7 @@ class TestDeprecatedHooks:
             """Old hook"""
             pass
 
-    def test_if_hook_raise_error(self, tmp_path):
+    def test_if_hook_raise_error(self, tmp_path: Path) -> None:
         """Deprecated hooks cannot be implemented and will raise an error."""
 
         # create a delta with default settings
@@ -350,7 +354,7 @@ class TestDeprecatedHooks:
 
 class TestUpdate:
 
-    def test_update(self, tmp_path):
+    def test_update(self, tmp_path: Path) -> None:
         # create a delta with default settings
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml')
         _delta = DeltaModel(input_file=p)
@@ -395,7 +399,7 @@ class TestUpdate:
         assert _delta.time_iter == int(2)
         assert _delta.time == 2 * _delta.dt
 
-    def test_update_is_finalized(self, tmp_path):
+    def test_update_is_finalized(self, tmp_path: Path) -> None:
         # create a delta with different itermax
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml')
         _delta = DeltaModel(input_file=p)
@@ -410,7 +414,7 @@ class TestUpdate:
 
 class TestFinalize:
 
-    def test_finalize_not_updated(self, tmp_path):
+    def test_finalize_not_updated(self, tmp_path: Path) -> None:
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml')
         _delta = DeltaModel(input_file=p)
 
@@ -432,7 +436,7 @@ class TestFinalize:
 
         assert _delta._is_finalized is True
 
-    def test_finalize_is_finalized(self, tmp_path):
+    def test_finalize_is_finalized(self, tmp_path: Path) -> None:
         # create a delta with different itermax
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml')
         _delta = DeltaModel(input_file=p)
@@ -449,7 +453,7 @@ class TestFinalize:
 
 class TestPublicSettersAndGetters:
 
-    def test_setting_getting_sea_surface_mean_elevation(self, tmp_path):
+    def test_setting_getting_sea_surface_mean_elevation(self, tmp_path: Path) -> None:
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml')
         _delta = DeltaModel(input_file=p)
 
@@ -457,7 +461,7 @@ class TestPublicSettersAndGetters:
         _delta.sea_surface_mean_elevation = 0.5
         assert _delta.sea_surface_mean_elevation == 0.5
 
-    def test_setting_getting_sea_surface_elevation_change(self, tmp_path):
+    def test_setting_getting_sea_surface_elevation_change(self, tmp_path: Path) -> None:
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml')
         _delta = DeltaModel(input_file=p)
 
@@ -465,7 +469,7 @@ class TestPublicSettersAndGetters:
         _delta.sea_surface_elevation_change = 0.002
         assert _delta.sea_surface_elevation_change == 0.002
 
-    def test_setting_getting_bedload_fraction(self, tmp_path):
+    def test_setting_getting_bedload_fraction(self, tmp_path: Path) -> None:
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml')
         _delta = DeltaModel(input_file=p)
 
@@ -473,7 +477,7 @@ class TestPublicSettersAndGetters:
         _delta.bedload_fraction = 0.25
         assert _delta.bedload_fraction == 0.25
 
-    def test_setting_getting_channel_flow_velocity(self, tmp_path):
+    def test_setting_getting_channel_flow_velocity(self, tmp_path: Path) -> None:
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml')
         _delta = DeltaModel(input_file=p)
 
@@ -494,7 +498,7 @@ class TestPublicSettersAndGetters:
         assert (_delta.create_boundary_conditions.called is True)
         assert (_delta.init_sediment_routers.called is True)
 
-    def test_setting_getting_channel_width(self, tmp_path):
+    def test_setting_getting_channel_width(self, tmp_path: Path) -> None:
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml')
         _delta = DeltaModel(input_file=p)
 
@@ -516,7 +520,7 @@ class TestPublicSettersAndGetters:
         assert (_delta.create_boundary_conditions.called is True)
         assert (_delta.init_sediment_routers.called is True)
 
-    def test_setting_getting_flow_depth(self, tmp_path):
+    def test_setting_getting_flow_depth(self, tmp_path: Path) -> None:
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml')
         _delta = DeltaModel(input_file=p)
 
@@ -537,7 +541,7 @@ class TestPublicSettersAndGetters:
         assert (_delta.create_boundary_conditions.called is True)
         assert (_delta.init_sediment_routers.called is True)
 
-    def test_setting_getting_influx_concentration(self, tmp_path):
+    def test_setting_getting_influx_concentration(self, tmp_path: Path) -> None:
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml')
         _delta = DeltaModel(input_file=p)
 
@@ -556,7 +560,7 @@ class TestPublicSettersAndGetters:
         assert (_delta.create_boundary_conditions.called is True)
         assert (_delta.init_sediment_routers.called is True)
 
-    def test_getter_nosetter_sea_surface_elevation(self, tmp_path):
+    def test_getter_nosetter_sea_surface_elevation(self, tmp_path: Path) -> None:
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml')
         _delta = DeltaModel(input_file=p)
 
@@ -569,7 +573,7 @@ class TestPublicSettersAndGetters:
             _delta.sea_surface_elevation = np.random.uniform(
                 0, 1, size=_delta.eta.shape)
 
-    def test_getter_nosetter_water_depth(self, tmp_path):
+    def test_getter_nosetter_water_depth(self, tmp_path: Path) -> None:
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml')
         _delta = DeltaModel(input_file=p)
 
@@ -582,7 +586,7 @@ class TestPublicSettersAndGetters:
             _delta.water_depth = np.random.uniform(
                 0, 1, size=_delta.eta.shape)
 
-    def test_getter_nosetter_bed_elevation(self, tmp_path):
+    def test_getter_nosetter_bed_elevation(self, tmp_path: Path) -> None:
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml')
         _delta = DeltaModel(input_file=p)
 
