@@ -1,6 +1,7 @@
 # unit tests for water_tools.py
 
 import pytest
+from pathlib import Path
 
 import numpy as np
 
@@ -12,9 +13,34 @@ from . import utilities
 from pyDeltaRCM import water_tools
 
 
+class TestWaterRoute:
+
+    def test_route_water(self, tmp_path: Path) -> None:
+        # create a delta with default settings
+        p = utilities.yaml_from_dict(tmp_path, 'input.yaml')
+        _delta = DeltaModel(input_file=p)
+
+        # mock top-level methods
+        _delta.log_info = mock.MagicMock()
+        _delta.init_water_iteration = mock.MagicMock()
+        _delta.run_water_iteration = mock.MagicMock()
+        _delta.compute_free_surface = mock.MagicMock()
+        _delta.finalize_water_iteration = mock.MagicMock()
+
+        # run the method
+        _delta.route_water()
+
+        # methods called
+        assert (_delta.log_info.called is True)
+        assert (_delta.init_water_iteration.call_count == _delta._itermax)
+        assert (_delta.run_water_iteration.call_count == _delta._itermax)
+        assert (_delta.compute_free_surface.call_count == _delta._itermax)
+        assert (_delta.finalize_water_iteration.call_count == _delta._itermax)
+
+
 class TestWaterRoutingWeights:
 
-    def test_get_weight_at_cell(self):
+    def test_get_weight_at_cell(self) -> None:
         # prepare necessary ingredients for test
         ind = (0, 4)
         np.random.seed(0)
@@ -28,11 +54,12 @@ class TestWaterRoutingWeights:
         theta = 1
         weight_sfc = np.array([0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=np.float64)
         weight_int = np.array([0, 0, 0, 0, 0, 1, 0, 1, 1], dtype=np.float64)
+        weight_mod = np.array([0, 0, 0, 0, 0, 1, 0, 1, 1], dtype=np.float64)
 
         # get weights back from the test
         wts = water_tools._get_weight_at_cell_water(
             ind, weight_sfc, weight_int, depth,
-            celltype, dry_thresh, gamma, theta)
+            weight_mod, celltype, dry_thresh, gamma, theta)
         assert np.all(wts[[0, 1, 2, 5]] == 0)
         assert wts[4] == 0
         assert np.any(wts[[3, 6, 7, 8]] != 0)
@@ -40,7 +67,7 @@ class TestWaterRoutingWeights:
 
 class TestInitWaterIteration:
 
-    def test_fields_updated(self, tmp_path):
+    def test_fields_updated(self, tmp_path: Path) -> None:
         # create a delta with default settings
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml')
         delta = DeltaModel(input_file=p)
@@ -75,7 +102,7 @@ class TestCheckForLoops:
     CTR = 4
     L0 = 1
 
-    def test_check_for_loops_no_loops(self):
+    def test_check_for_loops_no_loops(self) -> None:
 
         # set up inds to go to new locations
         new_inds0 = np.array([76, 73])
@@ -92,7 +119,7 @@ class TestCheckForLoops:
         # no loops
         assert np.all(looped == [0, 0])
 
-    def test_check_for_loops_relocate_not_loop(self):
+    def test_check_for_loops_relocate_not_loop(self) -> None:
         """
         Will relocate parcel (repeated ind), but will not mark as a loop,
         because parcel stage is at SL.
@@ -115,7 +142,7 @@ class TestCheckForLoops:
         # one loop
         assert np.all(looped == [0, 0])
 
-    def test_check_for_loops_relocate_and_loop(self):
+    def test_check_for_loops_relocate_and_loop(self) -> None:
         """
         Will relocate parcel (repeated ind), and mark as a loop, because
         parcel stage is not at SL.
@@ -141,7 +168,7 @@ class TestCheckForLoops:
 
 class TestCalculateNewInds:
 
-    def test_calculate_new_inds(self, tmp_path):
+    def test_calculate_new_inds(self, tmp_path: Path) -> None:
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml')
         delta = DeltaModel(input_file=p)
 
@@ -163,7 +190,7 @@ class TestCalculateNewInds:
 
 class TestUpdateQFields:
 
-    def test_update_dirQfield(self):
+    def test_update_dirQfield(self) -> None:
         # configure necessary ingredients
         np.random.seed(0)
         qx = np.random.uniform(0, 10, 9)
@@ -183,7 +210,7 @@ class TestUpdateQFields:
         # assertions
         assert np.all(qxdiff[3:6] == pytest.approx(qxdiff_exp))
 
-    def test_update_absQfield(self):
+    def test_update_absQfield(self) -> None:
         # configure necessary ingredients
         np.random.seed(0)
         qw = np.random.uniform(0, 10, 9)
@@ -209,7 +236,7 @@ class TestUpdateQFields:
 
 class TestUpdateFlowField:
 
-    def test_update_flow_field_time0_iteration0(self, tmp_path):
+    def test_update_flow_field_time0_iteration0(self, tmp_path: Path) -> None:
         """
         Check that the flow at the inlet is set as expected
         """
@@ -238,7 +265,7 @@ class TestUpdateFlowField:
 
         assert delta.log_info.call_count == 1
 
-    def test_update_flow_field_time1_iteration0(self, tmp_path):
+    def test_update_flow_field_time1_iteration0(self, tmp_path: Path) -> None:
         """
         Check that the flow in domain is set as expected when no flow (qx &
         qy==0)
@@ -268,7 +295,7 @@ class TestUpdateFlowField:
 
         assert delta.log_info.call_count == 1
 
-    def test_update_flow_field_time1_iteration1(self, tmp_path):
+    def test_update_flow_field_time1_iteration1(self, tmp_path: Path) -> None:
         """
         Check that the flow in domain is set as expected when no flow (qx &
         qy==0)
@@ -298,7 +325,7 @@ class TestUpdateFlowField:
 
         assert delta.log_info.call_count == 1
 
-    def test_update_velocity_field(self, tmp_path):
+    def test_update_velocity_field(self, tmp_path: Path) -> None:
         """
         Check that flow velocity field is updated as expected
         """
